/* Script 8.8 - editFunctions.js (updated)
 * This script defines the JavaScript functions used to Copy, Cut, and Paste.
 */

// Function for copying data to the clipboard.
// Takes one argument: an event.
function doCopy(e) {
	e.preventDefault();
	e.clipboardData.clearData();

	// Is the selection an image?
	if (e.target instanceof HTMLImageElement) {

		// Add the image to the clipboard:
		e.clipboardData.setData('image/x-vnd.adobe.air.bitmap', e.target);

	} else { // Text!

		// Get the selection:
		var data = window.getSelection();

		// Add the text to the clipboard:
		e.clipboardData.setData('text/plain', data);

	}

} // End of doCopy() function.

// Function for cutting data.
// Takes one argument: an event.
function doCut(e){
	doCopy(e);
	var data = window.getSelection();
	var r = data.getRangeAt(0);
	r.deleteContents();
} // End of doCut() function.

// Function for pasting data from the clipboard.
// Takes one argument: an event.
function doPaste(e) {

	// Paste text as a new DIV:
	if (e.clipboardData.getData('text/plain')) {

		addDiv( e.clipboardData.getData('text/plain') );

	} else if (e.clipboardData.getData('image/x-vnd.adobe.air.bitmap')) { // Image!

		var image = e.clipboardData.getData('image/x-vnd.adobe.air.bitmap');

		// Create a new DIV:
		var d = document.createElement('div');

		document.body.appendChild(image);
		// Add the DIV to the page:
		document.body.appendChild(d);

		// Add a break:
		document.body.appendChild(document.createElement('br'));

	} else {

		alert('Data type not yet supported!');

	}

} // End of doPaste() function.

// Function for adding new content in a DIV.
// Takes one argument: the content to be added.
function addDiv(content) {
	var d = document.createElement('div');
	d.innerText = content;
	document.body.appendChild(d);
	document.body.appendChild(document.createElement('br'));
} // End of addDiv() function.
